@@ -1,7 +1,9 @@
 package App::genpw;
 
-our $DATE = '2018-07-01'; # DATE
-our $VERSION = '0.009'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-21'; # DATE
+our $DIST = 'App-genpw'; # DIST
+our $VERSION = '0.010'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,6 +24,16 @@ my $base64characters   = ["A".."Z","a".."z","0".."9","+","/"];
 my $base58characters   = [split //, q(ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz123456789)]; # %b
 my $base56characters   = [split //, q(ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnpqrstuvwxyz23456789)];   # %B
 
+our %arg_action = (
+    action => {
+        schema => ['str*', in=>[qw/gen list-patterns/]],
+        default => 'gen',
+        cmdline_aliases => {
+            list_patterns => {summary=>'Shortcut for --action=list-patterns', is_flag=>1, code=>sub { $_[0]{action} = 'list-patterns' }},
+        },
+    },
+);
+
 our %arg_patterns = (
     patterns => {
         'x.name.is_plural' => 1,
@@ -210,6 +222,7 @@ then:
 
 _
     args => {
+        %arg_action,
         num => {
             schema => ['int*', min=>1],
             default => 1,
@@ -262,12 +275,17 @@ _
 sub genpw {
     my %args = @_;
 
+    my $action = $args{action} // 'gen';
     my $num = $args{num} // 1;
     my $min_len = $args{min_len} // $args{len} // 12;
     my $max_len = $args{max_len} // $args{len} // 20;
     my $patterns = $args{patterns} // ["%$min_len\$${max_len}B"];
     my $case = $args{case} // 'default';
 
+    if ($action eq 'list-patterns') {
+        return [200, "OK", $patterns];
+    }
+
   GET_WORDS_FROM_STDIN:
     {
         last if defined $args{_words};
@@ -306,7 +324,7 @@ App::genpw - Generate random password, with patterns and wordlists
 
 =head1 VERSION
 
-This document describes version 0.009 of App::genpw (from Perl distribution App-genpw), released on 2018-07-01.
+This document describes version 0.010 of App::genpw (from Perl distribution App-genpw), released on 2020-05-21.
 
 =head1 SYNOPSIS
 
@@ -319,7 +337,7 @@ See the included script L<genpw>.
 
 Usage:
 
- genpw(%args) -> [status, msg, result, meta]
+ genpw(%args) -> [status, msg, payload, meta]
 
 Generate random password, with patterns and wordlists.
 
@@ -398,6 +416,8 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<action> => I<str> (default: "gen")
+
 =item * B<case> => I<str> (default: "default")
 
 Force casing.
@@ -442,6 +462,7 @@ be used as-is. Available conversions:
  %%   A literal percent sign
  %w   Random word
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -449,7 +470,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -471,24 +492,13 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-
-L<genpw-base56>.
-
-L<genpw-base64>.
-
-L<genpw-id>.
-
-L<genpw-wordlist>.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
